OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Versões",
    "Failed to revert {file} to revision {timestamp}." : "Falhou a recuperação do ficheiro {file} para a revisão {timestamp}.",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Restore" : "Restaurar",
    "No other versions available" : "Nenhuma outra versão disponível"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
